import sys
from jkspy.modules import hash
from Crypto.PublicKey import RSA
from jkspy.helpers import readFile, writeFile

def test():
    print(">>> Running jkspy TEST")
    for i in range(0, 10):
        print(i)
    print(">>> TEST Completed")
    
def checksum(filepath, *options):
    try:
        print(hash.get_checksum(filepath, *options))
    except TypeError:
        print("Please provide a filepath.")
        print("  (Example)  >> jkspy checksum test.txt")

def keygen(filepath, kind=16, format='PEM'):
    if int(kind) > 0:
        keyfile = open(filepath, 'wb')
        keyfile.write(hash.make_key(int(kind)))
        keyfile.close()
        print("New random key created at "+filepath)
    elif kind == 'pair':
        keypair = hash.make_keypair()
        hash.save_keypair(keypair, filepath, format)
        print("New keypair created as "+filepath+'.private and '+filepath+'.public')
    
def encrypt(pubkeypath, filepath):
    pubkey = hash.open_keypair(pubkeypath)
    content = readFile(filepath)
    
    crypto = hash.encrypt(pubkey, content)
    
    writeFile(filepath+'.secret', crypto, True)
    
def decrypt(prvkeypath, filepath):
    try:
        prvkey = hash.open_keypair(prvkeypath)
        content = readFile(filepath, True)
        
        plain = hash.decrypt(prvkey, content).decode()
        
        writeFile(filepath+'.plain', plain)
    except ValueError:
        print("Could not decrypt ["+filepath+"]")


#!/usr/bin/python3
import sys
try:
    from jkspy.modules.hash import get_checksum

    def help(alert):
        print("\n"+alert)
        print("----------------------------------\nExample:\n----------------------------------")
        print("  root@localhost:~$ checksum /home/user/downloaded.zip sha256")
        print("----------------------------------\n")
    
    try:
        print(get_checksum(*sys.argv[1:]))
    except FileNotFoundError:
        help("File [ "+sys.argv[1]+" ] could not be found. Please type the correct path.")
    except AttributeError:
        help("[ "+sys.argv[2]+" ] is not a supported algorithm")

except ImportError:
    print("Could not locate library 'jkspy', please install by typing 'pip3 install jkspy'")


import os, json
from jkspy.modules import hash

class Saveable():
    def __init__(self, *args, **kwargs):
        return super(Saveable, self).__init__(*args, **kwargs)
    
    def save(self):
        attrs = [attr for attr in dir(self) if not attr.startswith('__') and not callable(getattr(self,attr))]
        result = {}
        for attr in attrs:
            aval = getattr(self, attr)
            if type(aval) == Saveable:
                result[attr] = aval.save()
            elif type(aval) in [str, int, float, bool]:
                result[attr] = getattr(self, attr)
        return json.dumps(result)
    
class PWStamp():
    def __init__(self, dtstamp, pw):
        self[dtstamp] = pw

class Keyper():        
    def __init__(self):
        self.status = 'Running'
        return
    
    def save(self):
        newpw = PWStamp('abdadsf','eslkjfleksjf')
        print(json.dumps(newpw))


#!/usr/bin/python3
import sys
import jkspy.cmdutils as utils

def help(alert):
    print("\n"+alert)
    print("----------------------------------\nExample:\n----------------------------------")
    print("  root@localhost:~$ jkspy keygen 'keypath/'")
    print("----------------------------------\n")
    
try:
#     print(sys.argv)
    try:
        try:
            utility = getattr(utils, sys.argv[1])
#             print(utility)
            if len(sys.argv) > 2:
                utility(*sys.argv[2:])
            else:
                utility()
        except IndexError:
            help('You should provide a command argument')

    except AttributeError:
        print("Unknown jkspy command '"+sys.argv[1]+"'")
        

except ImportError:
    print("Could not locate library 'jkspy', please install by typing 'pip3 install jkspy'")